import Image from "next/image";

import { getTranslations } from "next-intl/server";

import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import { ContactButtons } from "@/components/sections/contact/contact-buttons";
import RequestForEmploymentForm from "@/components/sections/request-for-employment/request-for-employment-form";
import PageBreadcrump from "@/components/shared/testing/page-breadcrump";
import { ImageBaseUrl } from "@/configs/api";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { LocaleParams } from "@/types/params";
import { HydrationBoundary, dehydrate } from "@tanstack/react-query";

async function RequestForEmploymentPage({ params }: { params: LocaleParams }) {
	const { locale } = await params;

	const t = await getTranslations("RequestForEmployment");

	const breadcrumbItems = [
		{
			href: "/",
			label: {
				en: "Home",
				ar: "الرئيسية",
			},
		},
		{
			href: "/request-for-employment",
			label: {
				en: "Request for employment",
				ar: "طلب توظيف",
			},
		},
	];

	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
	]);

	const _data = queryClient.getQueryData<any>(["basicInfo"]);

	const _requestForEmployment = _data?.data?.pages_headers?.find((val: any) => val.page == "job application");


	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<section>
				<Header />
				<PageBreadcrump
					locale={locale}
					subtitle={{
						en: _requestForEmployment?.text?.en,
						ar: _requestForEmployment?.text?.ar,
					}}
					title={{
						en: _requestForEmployment?.description?.en,
						ar: _requestForEmployment?.description?.ar,
					}}
					breadcrumbItems={breadcrumbItems}
				/>
				<div className="mx-auto max-w-7xl px-2 sm:px-2 md:px-4 lg:px-4 xl:px-24">
					<div className="mb-6 mt-2 flex items-center justify-center">
						<p className="border-b-2 border-solid border-custom-primary-accent px-12 py-2 text-[32px] text-custom-primary-accent md:text-[42px]">
							{t("JoinOurTeam")}
						</p>
					</div>

					<RequestForEmploymentForm />

					<div className="container mx-auto my-20 max-w-7xl">
						<ContactButtons />
					</div>
				</div>
				<div className="relative mt-12 h-[569px] w-full">
					<Image
						src={ImageBaseUrl + _requestForEmployment?.page_image}
						alt=""
						fill
						priority
						style={{ objectFit: "cover" }}
					/>
				</div>
				<Footer />
			</section>
		</HydrationBoundary>
	);
}

export default RequestForEmploymentPage;
